# Script for creating a 3D surface from x, y, and z coordinates in vectors read from Pajek.
# Script assumes that the islands height vector and the x and y coordinate vectors were exported from Pajek to R.

# USER: ASSIGN THE RIGHT VECTORS TO THE x, y, AND ISLAND height VECTOR.
# In this example: vector 3 (v3) contains the x coordinate, v4 the y coordinate, and v2 the island height (z).
x <- v3
y <- v4
z <- v2
 
# Load package akima.
# USER: The very first time, you must download the package akima using the Packages>Install package(s) command
# In the first dialogue box, select a mirror (location to be downloaded from).
# In the second dialogue box, select the akima package.
library(akima)

# Split screen for outputting both a map and a landscape.
split.screen(c(2,1))

# Adding corners with height zero (to fill the landscape to the margins).
x2 <- append(x, c(0, 0, 1, 1))
y2 <- append(y, c(0, 1, 0, 1))
z2 <- append(z, c(0, 0, 0, 0))
# Adding 0.5 to height to ensure that island height corresponds with contour numbering.
z2 <- z2 + 0.5

# Assemble a data frame from the 3 coordinates vectors.
thedata<-data.frame(x,y,z)
summary(thedata)

# Linear interpolation of z values.
# For smoother/coarser image, change value of 'length'.
thedata.lin <- with(thedata, interp(x2,y2,z2, xo=seq(0, 1, length=200), yo=seq(0, 1, length=200), linear=TRUE, duplicate="mean"))

# Select the first half of the screen.
screen(1)

# Map with contours.
plot(c(0, 0, 1, 1), c(0, 1, 0, 1), type="n", xlab="", ylab="", cex.axis=0.6, main=paste("Map: linear interpolation"), xaxt="n", yaxt="n")
image (thedata.lin, add=TRUE, col = terrain.colors(max(z) + 1)) #One color for each island level
contour (thedata.lin, add=TRUE, lwd = 0.4, lty = 1)
points(x, y, pch=19)

# Select the second half of the screen.
screen(2)

# 3D plot.
# If you want to flatten the landscape, lower 'expand'.
# If you want to rotate the plane, change the value of 'theta'.
# If you want to rotate the lighting, change the value of 'ltheta'.
# If you want to look more from the top, raise the value of 'phi'.
# If you want to change the lighting, change the value of 'ltheta'.
# If you want to have heavier shadows, raise the value of 'shade'.
persp(x=thedata.lin$x, y=thedata.lin$y, z=thedata.lin$z, expand=0.2, theta=45, col = "lightgray", ltheta = 240, phi=10, shade = 0.5, axes=FALSE, border=NA, r = 10, cex=1.0)

# Exit split screen mode.
close.screen(all = TRUE)