# Script for creating loglog plots and an estimation of the power law exponent.
# Script assumes that a vector called "v2" containing the degree of vertices was exported from Pajek to R.

# USER: ASSIGN THE RIGHT PAJEK VECTOR TO x.
# In this example: vector 2 (v2) contains the degree distribution. Change the number 2 if necessary.
x <- v2
summary(x)

# USER: The very first time, you must download the package igraph using the Packages>Install package(s) command
# In the first dialogue box, select a mirror (location to be downloaded from).
# In the second dialogue box, select the igraph package.
# Load package igraph for fitting a power law to the degree distribution.
library(igraph)

# Split output screen into two panels.
split.screen(c(1,2))

# Select the left panel of the screen.
screen(1)
# Create a simple log-log graph of the degree distribution.
# Automatically omits degrees with zero frequency.
plot (tabulate(x), log = "xy", ylab = "Frequency (log scale)", xlab = "Degree (log scale)", main = "Log-log plot of degree distribution", cex.main = 0.9, cex.lab = 0.9, cex.axis = 0.9)

# Select the right panel of the screen.
screen(2)
# Create a cumulative relative degree distribution plot.
# Determine the ranks of the vertices with respect to their degree.
y <- (length(x) - rank(x, ties.method = "first"))/length(x)
plot(x, y, log = "xy", ylab = "Fraction with min. degree k (log scale)", xlab = "Degree (k) (log scale)", main = "Cumulative log-log plot of degree distribution", cex.main = 0.9, cex.lab = 0.9, cex.axis = 0.9)

# Exit split screen mode.
close.screen(all = TRUE)

# Calculate alpha with the igraph package.
# Increase/decrease xmin to change the minimum degree taken into account. 
power.law.fit(x, xmin = 50)

